@@ -10,12 +10,13 @@
 from .sources import load as load_source
 from .datasets import load as load_dataset
 from .plotting import plot_map, new_plot
-
+from .core.settings import SETTINGS as settings
+from .core.caching import CACHE as cache
 
 from climetlab.sources import DataSource
 from climetlab.datasets import Dataset
 
-__version__ = "0.0.60"
+__version__ = "0.0.66"
 
 
 __all__ = [
@@ -23,6 +24,8 @@ __all__ = [
     "load_dataset",
     "plot_map",
     "new_plot",
+    "settings",
+    "cache",
     "Dataset",
     "DataSource",
 ]
