@@ -3,8 +3,8 @@
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation nor
-# does it submit to any jurisdiction.
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
 #
 
 
@@ -15,7 +15,7 @@ import climetlab
 
 def _find(collection, yaml_file, fail):
     top = os.path.dirname(climetlab.__file__)
-    for path, dirs, files in os.walk(top):
+    for path, _, files in os.walk(top):
         if os.path.basename(path) == collection:
             if yaml_file in files:
                 return os.path.join(path, yaml_file)
