@@ -3,8 +3,8 @@
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation nor
-# does it submit to any jurisdiction.
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
 #
 
 import numpy as np
@@ -12,7 +12,7 @@ import xarray as xr
 
 
 class XArrayHelper:
-    def __init__(self, data, *args, **kwargs):
+    def __init__(self, data):
 
         self.data = data
         for name, var in data.data_vars.items():
@@ -31,8 +31,6 @@ class XArrayHelper:
         self.east = np.amax(data[lon].data)
         self.west = np.amin(data[lon].data)
 
-        self.kwargs = kwargs
-
     def plot_map(self, driver):
         driver.bounding_box(
             north=self.north, south=self.south, west=self.west, east=self.east
@@ -44,7 +42,6 @@ class XArrayHelper:
             dimension_settings[d] = 0  # self.data[d].data[0]
 
         driver.plot_xarray(self.data, self.name, dimension_settings)
-        driver.apply_kwargs(self.kwargs)
 
 
 def helper(data, *args, **kwargs):
